==> dnacentersdk-2.3.3.tar.gz: dnacentersdk-2.3.3/dnacentersdk/models/validators/v2_2_2_3/jsd_cf2cac6f150c9bee9ade37921b162.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center CreateDeviceCredentials data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidatorCf2CaC6F150C9Bee9Ade37921B162(object):
    """CreateDeviceCredentials request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorCf2CaC6F150C9Bee9Ade37921B162, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "settings": {
                "properties": {
                "cliCredential": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "enablePassword": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsRead": {
                "items": {
                "properties": {
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "number"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsWrite": {
                "items": {
                "properties": {
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "number"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cRead": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "readCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cWrite": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "writeCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV3": {
                "items": {
                "properties": {
                "authPassword": {
                "type": "string"
                },
                "authType": {
                "enum": [
                "SHA",
                "MD5"
                ],
                "type": "string"
                },
                "description":
                 {
                "type": "string"
                },
                "privacyPassword": {
                "type": "string"
                },
                "privacyType": {
                "enum": [
                "AES128",
                "DES"
                ],
                "type": "string"
                },
                "snmpMode": {
                "enum": [
                "AUTHPRIV",
                "AUTHNOPRIV",
                "NOAUTHNOPRIV"
                ],
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.4.1.tar.gz: dnacentersdk-2.4.1/dnacentersdk/models/validators/v2_2_1/jsd_cf2cac6f150c9bee9ade37921b162.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center createDeviceCredentials data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidatorCf2CaC6F150C9Bee9Ade37921B162(object):
    """createDeviceCredentials request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorCf2CaC6F150C9Bee9Ade37921B162, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "settings": {
                "properties": {
                "cliCredential": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "enablePassword": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsRead": {
                "items": {
                "properties": {
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "number"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "httpsWrite": {
                "items": {
                "properties": {
                "name": {
                "type": "string"
                },
                "password": {
                "type": "string"
                },
                "port": {
                "type": "number"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cRead": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "readCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV2cWrite": {
                "items": {
                "properties": {
                "description":
                 {
                "type": "string"
                },
                "writeCommunity": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "snmpV3": {
                "items": {
                "properties": {
                "authPassword": {
                "type": "string"
                },
                "authType": {
                "enum": [
                "SHA",
                "MD5"
                ],
                "type": "string"
                },
                "description":
                 {
                "type": "string"
                },
                "privacyPassword": {
                "type": "string"
                },
                "privacyType": {
                "enum": [
                "AES128",
                "DES"
                ],
                "type": "string"
                },
                "snmpMode": {
                "enum": [
                "AUTHPRIV",
                "AUTHNOPRIV",
                "NOAUTHNOPRIV"
                ],
                "type": "string"
                },
                "username": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }
                },
                "type": "object"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
